pub trait Halo2Types<F: Field> {
type InstanceCol: Debug + Copy + Clone;
type AdviceCol: Debug + Copy + Clone;
type Cell: Debug + Copy + Clone;
type AssignedCell<V>;
type Region<'a>;
type Error: Into<Error> + From<Error>;
type RegionIndex: Hash + Copy + Eq;
type Expression;
type Rational;
}Expand description
This trait defines the halo2 types required by this crate. An implementation of halo2 compatible with this crate must have some type that implements this trait s.t. it can be passed to traits and types in this crate.
Required Associated Types
Sourcetype InstanceCol: Debug + Copy + Clone
type InstanceCol: Debug + Copy + Clone
Type for instance columns.
Sourcetype AssignedCell<V>
type AssignedCell<V>
Type for an assigned cell.
Sourcetype RegionIndex: Hash + Copy + Eq
type RegionIndex: Hash + Copy + Eq
Region index type
Sourcetype Expression
type Expression
Expression type
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".